@@ -125,7 +125,7 @@ def choose_editor(default=None):
             question("Which code editor do you want to use?"),
             default=default
         )
-        if editor_installed(ed) or ed in ['subl', 'charm']:
+        if editor_installed(ed) or ed in ['atom', 'subl', 'charm']:
             return ed
         click.echo(error(f"Couldn't find {ed}. Double-check that it's installed."))
 
